from .xcolor import *

__all__ = [
    "Color",
    "color",
    "BLACK",
    "RED",
    "GREEN",
    "YELLOW",
    "BLUE",
    "PURPLE",
    "CYAN",
    "WHITE",
    "IBLACK",
    "IRED",
    "IGREEN",
    "IYELLOW",
    "IBLUE",
    "IPURPLE",
    "ICYAN",
    "IWHITE",
    "UBLACK",
    "URED",
    "UGREEN",
    "UYELLOW",
    "UBLUE",
    "UPURPLE",
    "UCYAN",
    "UWHITE",
    "TBLACK",
    "TRED",
    "TGREEN",
    "TYELLOW",
    "TBLUE",
    "TPURPLE",
    "TCYAN",
    "TWHITE",
    "test_color",
    "test_style",
]



from setuptools import setup

setup(
    author = "Max",
    author_email = "max@artsoft.io",
    license = "MIT",
    name = "xcolor",
    version = "1.6.2",
    keywords = "color print ColorPrint python3",
    url = "https://github.com/artsoftio/xcolor",
    install_requires = [],
    packages = ['xcolor'],
    description = "终端彩色打印",
    long_description = open("README.md").read(),
    long_description_content_type='text/markdown',
    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: POSIX",
    ]
)